package ru.lifepay.checkout.demo

import android.app.Activity
import android.content.Intent
import android.os.Bundle

object DefaultResponseHandler {

    sealed class Response {
        data class Success(val action: String, val extras: Bundle): Response()
        data class Error(val action: String, val extras: Bundle): Response()
        object NoResponse: Response()
    }

    fun handleActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Response {
        if (resultCode == Activity.RESULT_OK) {
            //Ответ получен.
            val intent = requireNotNull(data)
            val extras = requireNotNull(intent.extras)
            val code = extras.getInt("code", -1)
            val action = data.action ?: ""
            return if (code == 0) {
                //Успешное завершение операции
                Response.Success(action, extras)
            } else {
                //Неуспешное завершение операции
                Response.Error(action, extras)
            }
        } else {
            //Отсутствует ответ от LIFE POS Checkout.
            return Response.NoResponse
        }
    }
}

fun DefaultResponseHandler.Response.Error.getErrorMessageWithCode(): String {
    val code = extras.getInt("code", -1)
    val message = extras.getString("message", "")

    return "Код ошибки: $code\n$message"
}

fun DefaultResponseHandler.Response.NoResponse.getNoResponseErrorMessage(): String {
    return "Отсутствует ответ от LIFE POS Checkout."
}

