package ru.lifepay.checkout.demo.auth

import android.app.Activity
import android.content.ActivityNotFoundException
import android.content.Intent
import ru.lifepay.checkout.demo.Actions
import ru.lifepay.checkout.demo.util.Logger

/**
 * Запрос по интентам для управления авторизацией в LIFE POS Checkout.
 */
class AuthRequest(val activity: Activity, val errorCallback: (message: String?) -> Unit) {

    /**
     * Проверить статус активации рабочего места
     */
    fun getActivationStatus() {
        sendRequest(intent = Intent(Actions.AUTH_ACTIVATION_STATUS))
    }

    /**
     * Активировать рабочее место
     */
    fun activationWorkplace(activationCode: String) {
        sendRequest(
            intent = Intent(Actions.AUTH_ACTIVATE_WORKPLACE)
                .putExtra("activation_code", activationCode)
        )
    }

    private fun sendRequest(intent: Intent) {
        Logger.logRequest(intent)
        try {
            activity.startActivityForResult(intent, 5555) //число 5555 взято просто так, можно использовать другое число.
        } catch (e: ActivityNotFoundException) {
            errorCallback.invoke("Приложение LIFE POS Checkout не установлено на устройстве. Необходимо установить приложение.")
        } catch (e: Throwable) {
            errorCallback.invoke(e.message)
        }
    }
}