package ru.lifepay.checkout.demo.paymentterminal

import ru.lifepay.common.extensions.GSONConverter
import ru.lifepay.periphery.models.paymentterminals.PTTransaction
import java.util.*

/**
 * Данные для оплаты через платежный терминал
 */
class PTOrder(
    //Сумма транзакции в копейках
    val amount: Long
    ) {

    var paymentTransactionRequestId: String
        private set

    var refundTransactionRequestId: String
        private set

    var cancellationTransactionRequestId: String
        private set

    init {
        paymentTransactionRequestId = createRequestId()
        refundTransactionRequestId = createRequestId()
        cancellationTransactionRequestId = createRequestId()
    }


    private var paymentTransactionJson: String? = null

    val paymentTransaction: PTTransaction?
        get() = paymentTransactionJson?.let {
            GSONConverter.fromJSON(it, PTTransaction::class.java)
        }

    private var refundOrCancellationTransactionJson: String? = null

    val refundOrCancellationTransaction: PTTransaction?
        get() = refundOrCancellationTransactionJson?.let {
            GSONConverter.fromJSON(it, PTTransaction::class.java)
        }


    fun updatePaymentTransactionRequestId() {
        paymentTransactionRequestId = createRequestId()
    }

    fun updateRefundTransactionRequestId() {
        refundTransactionRequestId = createRequestId()
    }

    fun updateCancellationTransactionRequestId() {
        cancellationTransactionRequestId = createRequestId()
    }


    fun setPaymentTransaction(transaction: PTTransaction) {
        this.paymentTransactionJson = transaction.toJSON()
    }

    fun setRefundOrCancellationTransaction(transaction: PTTransaction) {
        this.refundOrCancellationTransactionJson = transaction.toJSON()
    }

    private fun createRequestId(): String {
        return UUID.randomUUID().toString()
    }
}