package ru.lifepay.checkout.demo.paymentterminal

import android.app.Activity
import android.content.ActivityNotFoundException
import android.content.Intent
import ru.lifepay.checkout.demo.Actions
import ru.lifepay.checkout.demo.data.LifepaySpecificDataRepository
import ru.lifepay.checkout.demo.util.Logger
import ru.lifepay.periphery.models.paymentterminals.PTTransaction
import java.io.Serializable

/**
 * Запрос по интентам через платежный терминал
 */
class PTRequest(val activity: Activity, val errorCallback: (message: String?) -> Unit) {

    /**
     * Оплата через платежный терминал
     */
    fun pay(
        requestId: String,
        metadata: HashMap<String, String>?,
        amount: Long
    ) {
        val lifepaySpecificData = LifepaySpecificDataRepository.getData()
        sendRequest(
            intent = Intent(Actions.PT_PAY)
                .putExtra("request_id", requestId)
                .putExtra("metadata", metadata)
                .putExtra("amount", amount)

                .apply {
                    putExtra("sign_on_screen", if (lifepaySpecificData.signOnScreen) "1" else "0")
                    if (!lifepaySpecificData.login.isNullOrEmpty()) {
                        putExtra("login", lifepaySpecificData.login)
                    }
                    if (!lifepaySpecificData.password.isNullOrEmpty()) {
                        putExtra("password", lifepaySpecificData.password)
                    }
                    if (!lifepaySpecificData.email.isNullOrEmpty()) {
                        putExtra("email", lifepaySpecificData.email)
                    }
                    if (!lifepaySpecificData.phone.isNullOrEmpty()) {
                        putExtra("phone", lifepaySpecificData.phone)
                    }
                    if (!lifepaySpecificData.recipientInn.isNullOrEmpty()) {
                        putExtra("recipient_inn", lifepaySpecificData.recipientInn)
                    }
                }
        )
    }

    /**
     * Возврат через платежный терминал
     */
    fun refund(
        requestId: String,
        amount: Long,
        primaryTransaction: PTTransaction
    ) {
        val lifepaySpecificData = LifepaySpecificDataRepository.getData()
        sendRequest(
            intent = Intent(Actions.PT_REFUND)
                .putExtra("request_id", requestId)
                .putExtra("amount", amount)
                .putExtra("primary_transaction", primaryTransaction.toJSON())

                .apply {
                    putExtra("sign_on_screen", if (lifepaySpecificData.signOnScreen) "1" else "0")
                    if (!lifepaySpecificData.login.isNullOrEmpty()) {
                        putExtra("login", lifepaySpecificData.login)
                    }
                    if (!lifepaySpecificData.password.isNullOrEmpty()) {
                        putExtra("password", lifepaySpecificData.password)
                    }
                }
        )
    }

    /**
     * Отмена оплаты через платежный терминал
     */
    fun cancel(
        requestId: String,
        amount: Long,
        primaryTransaction: PTTransaction
    ) {
        val lifepaySpecificData = LifepaySpecificDataRepository.getData()
        sendRequest(
            intent = Intent(Actions.PT_CANCEL)
                .putExtra("request_id", requestId)
                .putExtra("amount", amount)
                .putExtra("primary_transaction", primaryTransaction.toJSON())

                .apply {
                    putExtra("sign_on_screen", if (lifepaySpecificData.signOnScreen) "1" else "0")
                    if (!lifepaySpecificData.login.isNullOrEmpty()) {
                        putExtra("login", lifepaySpecificData.login)
                    }
                    if (!lifepaySpecificData.password.isNullOrEmpty()) {
                        putExtra("password", lifepaySpecificData.password)
                    }
                }
        )
    }

    /**
     * Получение результата транзакции через платежный терминал
     */
    fun getResult(
        requestId: String,
        metadata: Serializable?
    ) {
        val lifepaySpecificData = LifepaySpecificDataRepository.getData()
        sendRequest(
            intent = Intent(Actions.PT_GET_RESULT)
                .putExtra("request_id", requestId)
                .putExtra("metadata", metadata)

                .apply {
                    if (!lifepaySpecificData.login.isNullOrEmpty()) {
                        putExtra("login", lifepaySpecificData.login)
                    }
                    if (!lifepaySpecificData.password.isNullOrEmpty()) {
                        putExtra("password", lifepaySpecificData.password)
                    }
                }
        )
    }

    /**
     * Сверка итогов через платежный терминал
     */
    fun closeShift() {
        sendRequest(Intent(Actions.PT_CLOSE_SHIFT))
    }

    private fun sendRequest(intent: Intent) {
        Logger.logRequest(intent)
        try {
            activity.startActivityForResult(intent, 5555) //число 5555 взято просто так, можно использовать другое число.
        } catch (e: ActivityNotFoundException) {
            errorCallback.invoke("Приложение LIFE POS Checkout не установлено на устройстве. Необходимо установить приложение.")
        } catch (e: Throwable) {
            errorCallback.invoke(e.message)
        }
    }
}