package ru.lifepay.checkout.demo.quickpaymentsterminal

import android.app.Activity
import android.content.ActivityNotFoundException
import android.content.Intent
import ru.lifepay.checkout.demo.Actions
import ru.lifepay.checkout.demo.util.Logger
import ru.lifepay.periphery.models.quickpayments.QPTransaction
import kotlin.collections.HashMap

/**
 * Запрос по интентам через СБП
 */
class QPRequest(val activity: Activity, val errorCallback: (message: String?) -> Unit) {

    /**
     * Оплата через СБП
     */
    fun pay(metadata: HashMap<String, String>?, amount: Long, purpose: String) {
        sendRequest(
            intent = Intent(Actions.QP_PAY)
                .putExtra("metadata", metadata)
                .putExtra("amount", amount)
                .putExtra("purpose", purpose)
        )
    }

    /**
     * Возврат через СБП
     */
    fun refund(
        requestId: String,
        metadata: HashMap<String, String>?,
        amount: Long,
        primaryTransaction: QPTransaction
    ) {
        sendRequest(
            intent = Intent(Actions.QP_REFUND)
                .putExtra("request_id", requestId)
                .putExtra("metadata", metadata)
                .putExtra("amount", amount)
                .putExtra("primary_transaction", primaryTransaction.toJSON())
        )
    }

    private fun sendRequest(intent: Intent) {
        Logger.logRequest(intent)
        try {
            activity.startActivityForResult(intent, 5555) //число 5555 взято просто так, можно использовать другое число.
        } catch (e: ActivityNotFoundException) {
            errorCallback.invoke("Приложение LIFE POS Checkout не установлено на устройстве. Необходимо установить приложение.")
        } catch (e: Throwable) {
            errorCallback.invoke(e.message)
        }
    }
}