package ru.lifepay.checkout.demo.quickpaymentsterminal

import ru.lifepay.checkout.demo.DefaultResponseHandler
import ru.lifepay.checkout.demo.Actions
import ru.lifepay.common.extensions.GSONConverter
import ru.lifepay.periphery.models.quickpayments.QPTransaction

class QPResponseHandler {

    fun handleSuccessResponse(response: DefaultResponseHandler.Response.Success) {
        when (response.action) {
            Actions.QP_PAY -> {
                val data = requireNotNull(response.extras.getString("transaction"))
                val transaction = GSONConverter.fromJSON(data, QPTransaction::class.java)

                /**
                 * Сохраняем транзакцию оплаты,
                 * чтобы иметь возможность сделать по ней возврат в будущем
                 */
                requireNotNull(QPOrderHolder.currentOrder).setPaymentTransaction(transaction)
            }
            Actions.QP_REFUND -> {
                val data = requireNotNull(response.extras.getString("transaction"))
                val transaction = GSONConverter.fromJSON(data, QPTransaction::class.java)

                /**
                 * Сохраняем транзакцию возврата.
                 */
                requireNotNull(QPOrderHolder.currentOrder).setRefundTransaction(transaction)
            }
            else -> {

            }
        }
    }

    fun handleErrorResponse(response: DefaultResponseHandler.Response.Error) {
        val errorType = response.extras.getString("error_type")
        when (response.action) {
            Actions.QP_PAY -> {
                /**
                 * Результат транзакции возврата неизвестен (unknown_result_error).
                 * Не обновляем request_id чтобы повторить операцию возврата с тем же request_id
                 */
            }
            Actions.QP_REFUND -> {
                if (errorType == "unknown_result_error") {
                    /**
                     * Результат транзакции возврата неизвестен (unknown_result_error).
                     * Не обновляем request_id чтобы повторить операцию возврата с тем же request_id
                     */
                } else {
                    /**
                     * Результат возврата известен (ошибка).
                     * Обновляем request_id для следующей попытки возврата.
                     */
                    requireNotNull(QPOrderHolder.currentOrder).updateRefundTransactionRequestId()
                }
            }
            Actions.PT_CLOSE_SHIFT -> {}

            //Другие действия
            else -> {}
        }
    }
}