package ru.lifepay.checkout.demo.ui

import android.annotation.SuppressLint
import android.content.pm.ActivityInfo
import android.os.Bundle
import android.view.MenuItem
import android.widget.CheckBox
import android.widget.EditText
import androidx.appcompat.app.AppCompatActivity
import ru.lifepay.checkout.demo.R
import ru.lifepay.checkout.demo.data.LifepaySpecificDataRepository

class ParametersActivity : AppCompatActivity() {

    lateinit var signOnScreenCheckBox: CheckBox
    lateinit var loginEditText: EditText
    lateinit var passwordEditText: EditText
    lateinit var emailEditText: EditText
    lateinit var phoneEditText: EditText
    lateinit var recipientInnEditText: EditText

    @SuppressLint("SourceLockedOrientationActivity")
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT
        setContentView(R.layout.activity_parameters)

        signOnScreenCheckBox = findViewById(R.id.signOnScreenCheckBox)
        loginEditText = findViewById(R.id.loginEditText)
        passwordEditText = findViewById(R.id.passwordEditText)
        emailEditText = findViewById(R.id.emailEditText)
        phoneEditText = findViewById(R.id.phoneEditText)
        recipientInnEditText = findViewById(R.id.recipientInnEditText)

        this.supportActionBar?.apply {
            title = "Настройки"
            setDisplayHomeAsUpEnabled(true)
            setDisplayShowHomeEnabled(true)
        }

        signOnScreenCheckBox.setOnClickListener {
            val lifepaySpecificData = LifepaySpecificDataRepository.getData()
            signOnScreenCheckBox.isChecked = !lifepaySpecificData.signOnScreen
            saveData()
        }

        updateUI()
    }

    private fun updateUI() {
        val lifepaySpecificData = LifepaySpecificDataRepository.getData()

        loginEditText.setText(lifepaySpecificData.login)
        passwordEditText.setText(lifepaySpecificData.password)
        signOnScreenCheckBox.isChecked = lifepaySpecificData.signOnScreen
        emailEditText.setText(lifepaySpecificData.email)
        phoneEditText.setText(lifepaySpecificData.phone)
        recipientInnEditText.setText(lifepaySpecificData.recipientInn)
    }

    private fun saveData() {
        val lifepaySpecificData = LifepaySpecificDataRepository.getData()
        lifepaySpecificData.signOnScreen = signOnScreenCheckBox.isChecked
        lifepaySpecificData.login = loginEditText.text.toString().trim()
        lifepaySpecificData.password = passwordEditText.text.toString().trim()
        lifepaySpecificData.email = emailEditText.text.toString().trim()
        lifepaySpecificData.phone = phoneEditText.text.toString().trim()
        lifepaySpecificData.recipientInn = recipientInnEditText.text.toString().trim()
        LifepaySpecificDataRepository.save(lifepaySpecificData)
    }

    override fun onPause() {
        saveData()
        super.onPause()
    }

    override fun onDestroy() {
        saveData()
        super.onDestroy()
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            android.R.id.home -> {
                onBackPressed()
                true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }

    override fun onBackPressed() {
        finish()
    }
}
