package ru.lifepay.checkout.demo.ui

import android.annotation.SuppressLint
import android.content.Intent
import android.content.pm.ActivityInfo
import android.os.Bundle
import android.view.MenuItem
import androidx.appcompat.app.AppCompatActivity
import kotlinx.android.synthetic.main.activity_periphery.*
import ru.lifepay.checkout.demo.DefaultResponseHandler
import ru.lifepay.checkout.demo.R
import ru.lifepay.checkout.demo.periphery.PRRequest
import ru.lifepay.checkout.demo.getErrorMessageWithCode
import ru.lifepay.checkout.demo.getNoResponseErrorMessage
import ru.lifepay.checkout.demo.util.Logger
import ru.lifepay.checkout.demo.util.Util
import ru.lifepay.checkout.demo.util.intentToString

class PeripheryActivity: AppCompatActivity() {

    @SuppressLint("SourceLockedOrientationActivity", "SetTextI18n")
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT
        setContentView(R.layout.activity_periphery)

        this.supportActionBar?.apply {
            title = "Управление оборудованием"
            setDisplayHomeAsUpEnabled(true)
            setDisplayShowHomeEnabled(true)
        }

        peripheryButton.setOnClickListener {
            createPeripheryDevicesManager().manageConnectedDevices()
        }
    }

    private fun createPeripheryDevicesManager() = PRRequest(
        activity = this,
        errorCallback = Util.showErrorCallback(this)
    )

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        Logger.logResponse(requestCode, resultCode, data)
        resultTextView.text = data.intentToString()

        val response = DefaultResponseHandler.handleActivityResult(
            requestCode = requestCode,
            resultCode = resultCode,
            data = data
        )
        when (response) {
            is DefaultResponseHandler.Response.Success -> {}
            is DefaultResponseHandler.Response.Error -> {
                Util.showError(this, response.getErrorMessageWithCode())
            }
            is DefaultResponseHandler.Response.NoResponse -> {
                Util.showError(this, response.getNoResponseErrorMessage())
            }
        }
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            android.R.id.home -> {
                onBackPressed()
                true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }

    override fun onBackPressed() {
        finish()
    }
}