package ru.lifepay.checkout.demo.ui

import android.annotation.SuppressLint
import android.content.Intent
import android.content.pm.ActivityInfo
import android.os.Bundle
import android.view.MenuItem
import android.view.View
import android.widget.Button
import android.widget.EditText
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import ru.lifepay.checkout.demo.*
import ru.lifepay.checkout.demo.quickpaymentsterminal.QPOrder
import ru.lifepay.checkout.demo.quickpaymentsterminal.QPOrderHolder
import ru.lifepay.checkout.demo.quickpaymentsterminal.QPRequest
import ru.lifepay.checkout.demo.quickpaymentsterminal.QPResponseHandler
import ru.lifepay.checkout.demo.util.Logger
import ru.lifepay.checkout.demo.util.Util
import ru.lifepay.checkout.demo.util.getCompactRepresentation
import ru.lifepay.checkout.demo.util.intentToString

class QuickPaymentsTerminalActivity : AppCompatActivity() {

    lateinit var paymentPriceEditText: EditText
    lateinit var clearDataButton: Button

    lateinit var payButton: Button
    lateinit var refundButton: Button

    lateinit var paymentContentTextView: TextView
    lateinit var refundContentTextView: TextView

    lateinit var lastIntentResultTextView: TextView

    @SuppressLint("SourceLockedOrientationActivity")
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT
        setContentView(R.layout.activity_quick_payments_terminal)

        this.supportActionBar?.apply {
            title = "СБП"
            setDisplayHomeAsUpEnabled(true)
            setDisplayShowHomeEnabled(true)
        }

        paymentPriceEditText = findViewById(R.id.paymentPriceEditText)
        clearDataButton = findViewById(R.id.clearDataButton)
        payButton = findViewById(R.id.payButton)
        refundButton = findViewById(R.id.refundButton)
        paymentContentTextView = findViewById(R.id.paymentContentTextView)
        refundContentTextView = findViewById(R.id.refundContentTextView)
        lastIntentResultTextView = findViewById(R.id.lastIntentResultTextView)

        payButton.setOnClickListener {
            val order = QPOrderHolder.currentOrder ?: run {
                val amount = getEnteredAmount()
                if (amount == null) {
                    Util.showError(this, "Введите сумму в копейках")
                    return@setOnClickListener
                }
                QPOrder(amount).also {
                    QPOrderHolder.currentOrder = it
                    updateUI()
                }
            }

            Util.hideKeyboard(this, paymentPriceEditText)

            createQuickPaymentsTerminalRequest().pay(
                metadata = hashMapOf("key_1" to "value_1", "key_2"  to "value_2"),
                amount = order.amount,
                purpose = "Test purpose"
            )
        }

        refundButton.setOnClickListener {
            val order = requireNotNull(QPOrderHolder.currentOrder)

            createQuickPaymentsTerminalRequest().refund(
                requestId = order.refundTransactionRequestId,
                amount = order.amount,
                primaryTransaction = requireNotNull(order.paymentTransaction),
                metadata = hashMapOf("key_1" to "value_1", "key_2"  to "value_2")
            )
        }

        clearDataButton.setOnClickListener {
            QPOrderHolder.currentOrder = null
            updateUI()
        }
        updateUI()
    }

    private fun getEnteredAmount(): Long? {
        return paymentPriceEditText.text.toString().toLongOrNull()
    }

    private fun createQuickPaymentsTerminalRequest() = QPRequest(
        activity = this,
        errorCallback = Util.showErrorCallback(this)
    )

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        Logger.logResponse(requestCode, resultCode, data)

        val response = DefaultResponseHandler.handleActivityResult(
            requestCode = requestCode,
            resultCode = resultCode,
            data = data
        )

        val responseHandler = QPResponseHandler()
        when (response) {
            is DefaultResponseHandler.Response.Success -> {
                responseHandler.handleSuccessResponse(response)
            }
            is DefaultResponseHandler.Response.Error -> {
                responseHandler.handleErrorResponse(response)
                Util.showError(this, response.getErrorMessageWithCode())
            }
            is DefaultResponseHandler.Response.NoResponse -> {
                Util.showError(this, response.getNoResponseErrorMessage())
            }
        }
        updateUI()
        lastIntentResultTextView.text = "Результат последнего запроса:\n${data.intentToString()}"
    }

    private fun updateUI() {
        val order = QPOrderHolder.currentOrder

        if (order == null) {
            paymentPriceEditText.text = null
            paymentPriceEditText.isEnabled = true
            clearDataButton.visibility = View.GONE
            payButton.visibility = View.VISIBLE
            refundButton.visibility = View.GONE
            paymentContentTextView.visibility = View.GONE
            refundContentTextView.visibility = View.GONE
            lastIntentResultTextView.text = ""
            Util.hideKeyboard(this, paymentPriceEditText)
        } else {
            paymentPriceEditText.setText(order.amount.toString())
            paymentPriceEditText.isEnabled = false
            clearDataButton.visibility = View.VISIBLE

            order.paymentTransaction.also { paymentTransaction ->
                payButton.visibility = if (paymentTransaction == null) View.VISIBLE else View.GONE
                paymentContentTextView.text = paymentTransaction?.getCompactRepresentation()
                paymentContentTextView.visibility = if (paymentTransaction != null) View.VISIBLE else View.GONE

                order.refundTransaction.also { refundTransaction ->
                    refundButton.visibility = if (refundTransaction == null && paymentTransaction != null)
                        View.VISIBLE else View.GONE
                    refundContentTextView.text = refundTransaction?.getCompactRepresentation()
                    refundContentTextView.visibility = if (refundTransaction != null) View.VISIBLE else View.GONE
                }
            }
        }
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            android.R.id.home -> {
                onBackPressed()
                true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }

    override fun onBackPressed() {
        finish()
    }
}