package ru.lifepay.checkout.demo.util

import android.content.Intent
import android.util.Log
import org.threeten.bp.OffsetDateTime
import org.threeten.bp.ZoneId
import org.threeten.bp.ZoneOffset
import org.threeten.bp.format.DateTimeFormatter
import ru.lifepay.periphery.models.paymentterminals.PTEOperations
import ru.lifepay.periphery.models.paymentterminals.PTTransaction
import ru.lifepay.periphery.models.quickpayments.QPEOperations
import ru.lifepay.periphery.models.quickpayments.QPTransaction
import java.util.*

object Logger {
    private val TAG = "LPCheckoutDemo"

    fun logResponse(requestCode: Int, resultCode: Int, data: Intent?) {
        val log = "onActivityResult\nresultCode: $resultCode\nrequestCode: $requestCode${data.intentToString()}"
        Log.i(TAG, log)
    }

    fun logRequest(intent: Intent) {
        Log.i(TAG, "input request${intent.intentToString()}")
    }
}

fun Intent?.intentToString(): String {
    var log = ""
    if (this != null) {
        log += "\naction: ${this.action}"
        val extras = this.extras
        if (extras != null) {
            for (key in extras.keySet()) {
                val value = extras.get(key)
                value?.let {
                    if (it is String && it.length > 2000) {
                        log += "\n$key: ${it.substring(0, 2000)}"
                    } else {
                        log += "\n$key: $it"
                    }
                }
            }
        } else {
            log += "\nextras is null"
        }
    } else {
        log += "\nintent is null"
    }
    return log
}

private fun OffsetDateTime.getUiPresentation(): String {
    val currentZoneId = ZoneId.ofOffset("UTC",
        ZoneOffset.ofTotalSeconds(Calendar.getInstance().timeZone.rawOffset/1000))
    return this.atZoneSameInstant(currentZoneId)
        .format(DateTimeFormatter.ofPattern("dd.MM.yy HH:mm", Locale.ENGLISH))
}

fun PTTransaction.getCompactRepresentation(): String {
    val title = when (operation) {
        PTEOperations.PAYMENT -> "Данные оплаты:"
        PTEOperations.REFUND -> "Данные возврата:"
        PTEOperations.CANCELLATION -> "Данные отмены оплаты:"
        else -> ""
    }
    return "\n$title\nдата и время:    ${registeredAt.getUiPresentation()}\n" +
            "ID терминала:    ${terminalId}\n" +
            "номер карты:     ${cardNumber}\n" +
            "номер ссылки:    ${referenceRetrievalNumber}\n" +
            "код авторизации: $authorizationCode"
}

fun QPTransaction.getCompactRepresentation(): String {
    val title = when (operation) {
        QPEOperations.PAYMENT -> "Данные оплаты:"
        QPEOperations.REFUND -> "Данные возврата:"
    }
    return "\n$title\nдата и время:    ${registeredAt.getUiPresentation()}\n" +
            "ID терминала:    ${terminalId}\n" +
            "ID мерчанта:     ${merchantId}\n" +
            "ID транзакции:     ${transactionId}\n" +
            "сумма:     ${this.amount}"
}